@@ -14,6 +14,7 @@ from rasterio.crs import CRS
 from rasterio.dtypes import validate_dtype, can_cast_dtype, get_minimum_dtype
 from rasterio.enums import MergeAlg
 from rasterio.env import ensure_env
+from rasterio.errors import ShapeSkipWarning
 from rasterio.rio.helpers import coords
 from rasterio.transform import Affine
 from rasterio.transform import IDENTITY, guard_transform
@@ -54,8 +55,13 @@ def geometry_mask(
 
     Returns
     -------
-    out : numpy ndarray of type 'bool'
+    numpy ndarray of type 'bool'
         Result
+
+    Notes
+    -----
+    See rasterize() for performance notes.
+
     """
     fill, mask_value = (0, 1) if invert else (1, 0)
 
@@ -70,11 +76,11 @@ def geometry_mask(
 
 @ensure_env
 def shapes(source, mask=None, connectivity=4, transform=IDENTITY):
-    """Yield (polygon, value for each set of adjacent pixels of the same value.
+    """Get shapes and values of connected regions in a dataset or array.
 
     Parameters
     ----------
-    source : array or dataset object opened in 'r' mode or Band or tuple(dataset, bidx)
+    source : array, dataset object, Band, or tuple(dataset, bidx)
         Data type must be one of rasterio.int16, rasterio.int32,
         rasterio.uint8, rasterio.uint16, or rasterio.float32.
     mask : numpy ndarray or rasterio Band object, optional
@@ -87,25 +93,30 @@ def shapes(source, mask=None, connectivity=4, transform=IDENTITY):
     connectivity : int, optional
         Use 4 or 8 pixel connectivity for grouping pixels into features
     transform : Affine transformation, optional
-        If not provided, feature coordinates will be generated based on pixel
-        coordinates
+        If not provided, feature coordinates will be generated based on
+        pixel coordinates
 
     Yields
     -------
-    tuple
+    polygon, value
         A pair of (polygon, value) for each feature found in the image.
-        Polygons are GeoJSON-like dicts and the values are the associated value
-        from the image, in the data type of the image.
-        Note: due to floating point precision issues, values returned from a
-        floating point image may not exactly match the original values.
+        Polygons are GeoJSON-like dicts and the values are the
+        associated value from the image, in the data type of the image.
+        Note: due to floating point precision issues, values returned
+        from a floating point image may not exactly match the original
+        values.
 
     Notes
     -----
-    The amount of memory used by this algorithm is proportional to the number
-    and complexity of polygons produced.  This algorithm is most appropriate
-    for simple thematic data.  Data with high pixel-to-pixel variability, such
-    as imagery, may produce one polygon per pixel and consume large amounts of
-    memory.
+    The amount of memory used by this algorithm is proportional to the
+    number and complexity of polygons produced.  This algorithm is most
+    appropriate for simple thematic data.  Data with high pixel-to-pixel
+    variability, such as imagery, may produce one polygon per pixel and
+    consume large amounts of memory.
+
+    Because the low-level implementation uses either an int32 or float32
+    buffer, uint32 and float64 data cannot be operated on without
+    truncation issues.
 
     """
     if hasattr(source, 'mask') and mask is None:
@@ -175,6 +186,10 @@ def rasterize(
         dtype=None):
     """Return an image array with input geometries burned in.
 
+    Warnings will be raised for any invalid or empty geometries, and
+    an exception will be raised if there are no valid shapes
+    to rasterize.
+
     Parameters
     ----------
     shapes : iterable of (`geometry`, `value`) pairs or iterable over
@@ -200,10 +215,10 @@ def rasterize(
         are selected by Bresenham's line algorithm will be burned in.
     merge_alg : MergeAlg, optional
         Merge algorithm to use. One of:
-            MergeAlg.replace (default): the new value will overwrite the
-              existing value.
-            MergeAlg.add: the new value will be added
-              to the existing raster.
+            MergeAlg.replace (default):
+                the new value will overwrite the existing value.
+            MergeAlg.add:
+                the new value will be added to the existing raster.
     default_value : int or float, optional
         Used as value for all geometries, if not provided in `shapes`.
     dtype : rasterio or numpy data type, optional
@@ -211,15 +226,27 @@ def rasterize(
 
     Returns
     -------
-    out : numpy ndarray
-        Results
+    numpy ndarray
+        If `out` was not None then `out` is returned, it will have been
+        modified in-place. If `out` was None, this will be a new array.
 
     Notes
     -----
     Valid data types for `fill`, `default_value`, `out`, `dtype` and
-    shape values are rasterio.int16, rasterio.int32, rasterio.uint8,
-    rasterio.uint16, rasterio.uint32, rasterio.float32,
-    rasterio.float64.
+    shape values are "int16", "int32", "uint8", "uint16", "uint32",
+    "float32", and "float64".
+
+    This function requires significant memory resources. The shapes
+    iterator will be materialized to a Python list and another C copy of
+    that list will be made. The `out` array will be copied and
+    additional temporary raster memory equal to 2x the smaller of `out`
+    data or GDAL's max cache size (controlled by GDAL_CACHEMAX, default
+    is 5% of the computer's physical memory) is required.
+
+    If GDAL max cache size is smaller than the output data, the array of
+    shapes will be iterated multiple times. Performance is thus a linear
+    function of buffer size. For maximum speed, ensure that
+    GDAL_CACHEMAX is larger than the size of `out` or `out_shape`.
 
     """
     valid_dtypes = (
@@ -265,25 +292,24 @@ def rasterize(
             value = default_value
         geom = getattr(geom, '__geo_interface__', None) or geom
 
-        # geom must be a valid GeoJSON geometry type and non-empty
-        if not is_valid_geom(geom):
-            raise ValueError(
-                'Invalid geometry object at index {0}'.format(index)
-            )
+        if is_valid_geom(geom):
+            shape_values.append(value)
 
-        if geom['type'] == 'GeometryCollection':
-            # GeometryCollections need to be handled as individual parts to
-            # avoid holes in output:
-            # https://github.com/mapbox/rasterio/issues/1253.
-            # Only 1-level deep since GeoJSON spec discourages nested
-            # GeometryCollections
-            for part in geom['geometries']:
-                valid_shapes.append((part, value))
+            if geom['type'] == 'GeometryCollection':
+                # GeometryCollections need to be handled as individual parts to
+                # avoid holes in output:
+                # https://github.com/mapbox/rasterio/issues/1253.
+                # Only 1-level deep since GeoJSON spec discourages nested
+                # GeometryCollections
+                for part in geom['geometries']:
+                    valid_shapes.append((part, value))
+
+            else:
+                valid_shapes.append((geom, value))
 
         else:
-            valid_shapes.append((geom, value))
-
-        shape_values.append(value)
+            # invalid or empty geometries are skipped and raise a warning instead
+            warnings.warn('Invalid or empty shape {} at index {} will not be rasterized.'.format(geom, index), ShapeSkipWarning)
 
     if not valid_shapes:
         raise ValueError('No valid geometry objects found for rasterize')
@@ -440,7 +466,8 @@ def geometry_window(dataset, shapes, pad_x=0, pad_y=0, north_up=True,
 def is_valid_geom(geom):
     """
     Checks to see if geometry is a valid GeoJSON geometry type or
-    GeometryCollection.
+    GeometryCollection.  Geometry must be GeoJSON or implement the geo
+    interface.
 
     Geometries must be non-empty, and have at least x, y coordinates.
 
@@ -458,15 +485,14 @@ def is_valid_geom(geom):
     geom_types = {'Point', 'MultiPoint', 'LineString', 'LinearRing',
                   'MultiLineString', 'Polygon', 'MultiPolygon'}
 
-    if 'type' not in geom:
-        return False
+    geom = getattr(geom, '__geo_interface__', None) or geom
 
     try:
-        geom_type = geom['type']
+        geom_type = geom["type"]
         if geom_type not in geom_types.union({'GeometryCollection'}):
             return False
 
-    except TypeError:
+    except (KeyError, TypeError):
         return False
 
     if geom_type in geom_types:
