@@ -1,29 +1,29 @@
-"""Merge command."""
+"""$ rio merge"""
 
-import logging
 
 import click
-from cligj import files_inout_arg, format_opt
+from cligj import format_opt
 
-from .helpers import resolve_inout
-from . import options
 import rasterio
+from rasterio.rio import options
+from rasterio.rio.helpers import resolve_inout
 
 
 @click.command(short_help="Merge a stack of raster datasets.")
-@files_inout_arg
+@options.files_inout_arg
 @options.output_opt
 @format_opt
 @options.bounds_opt
 @options.resolution_opt
 @options.nodata_opt
-@options.force_overwrite_opt
-@click.option('--precision', type=int, default=7,
+@options.bidx_mult_opt
+@options.overwrite_opt
+@click.option('--precision', type=int, default=10,
               help="Number of decimal places of precision in alignment of "
                    "pixels")
 @options.creation_options
 @click.pass_context
-def merge(ctx, files, output, driver, bounds, res, nodata, force_overwrite,
+def merge(ctx, files, output, driver, bounds, res, nodata, bidx, overwrite,
           precision, creation_options):
     """Copy valid pixels from input files to an output file.
 
@@ -46,22 +46,24 @@ def merge(ctx, files, output, driver, bounds, res, nodata, force_overwrite,
     """
     from rasterio.merge import merge as merge_tool
 
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-
     output, files = resolve_inout(
-        files=files, output=output, force_overwrite=force_overwrite)
+        files=files, output=output, overwrite=overwrite)
 
-    with rasterio.Env(CPL_DEBUG=verbosity > 2):
-        sources = [rasterio.open(f) for f in files]
-        dest, output_transform = merge_tool(sources, bounds=bounds, res=res,
-                                            nodata=nodata, precision=precision)
+    with ctx.obj['env']:
+        datasets = [rasterio.open(f) for f in files]
+        dest, output_transform = merge_tool(datasets, bounds=bounds, res=res,
+                                            nodata=nodata, precision=precision,
+                                            indexes=(bidx or None))
 
-        profile = sources[0].profile
-        profile.pop('affine')
+        profile = datasets[0].profile
         profile['transform'] = output_transform
         profile['height'] = dest.shape[1]
         profile['width'] = dest.shape[2]
         profile['driver'] = driver
+        profile['count'] = dest.shape[0]
+
+        if nodata is not None:
+            profile['nodata'] = nodata
 
         profile.update(**creation_options)
 
@@ -70,7 +72,7 @@ def merge(ctx, files, output, driver, bounds, res, nodata, force_overwrite,
 
             # uses the colormap in the first input raster.
             try:
-                colormap = sources[0].colormap(1)
+                colormap = datasets[0].colormap(1)
                 dst.write_colormap(1, colormap)
             except ValueError:
                 pass
