@@ -19,26 +19,59 @@ def build_handler(ctx, param, value):
                 base, exp_range = value.split('^')
                 exp_min, exp_max = (int(v) for v in exp_range.split('..'))
                 value = [pow(int(base), k) for k in range(exp_min, exp_max + 1)]
-            else:
+            elif ',' in value:
                 value = [int(v) for v in value.split(',')]
+            elif value == "auto":
+                pass
+            else:
+                raise Exception
         except Exception:
-            raise click.BadParameter(u"must match 'n,n,n,…' or 'n^n..n'.")
+            raise click.BadParameter(u"must match 'n,n,n,…', 'n^n..n', or 'auto'.")
     return value
 
 
+def get_maximum_overview_level(width, height, minsize=256):
+    """
+    Calculate the maximum overview level of a dataset at which
+    the smallest overview is smaller than `minsize`.
+
+    Attributes
+    ----------
+    width : int
+        Width of the dataset.
+    height : int
+        Height of the dataset.
+    minsize : int (default: 256)
+        Minimum overview size.
+
+    Returns
+    -------
+    overview_level: int
+        overview level.
+
+    """
+    overview_level = 0
+    overview_factor = 1
+    while min(width // overview_factor, height // overview_factor) > minsize:
+        overview_factor *= 2
+        overview_level += 1
+
+    return overview_level
+
+
 @click.command('overview', short_help="Construct overviews in an existing dataset.")
 @options.file_in_arg
-@click.option('--build', callback=build_handler, metavar=u"f1,f2,…|b^min..max",
-              help="A sequence of decimation factors specied as "
+@click.option('--build', callback=build_handler, metavar=u"f1,f2,…|b^min..max|auto",
+              help="A sequence of decimation factors specified as "
                    "comma-separated list of numbers or a base and range of "
-                   "exponents.")
+                   "exponents, or 'auto' to automatically determine the maximum factor.")
 @click.option('--ls', help="Print the overviews for each band.",
               is_flag=True, default=False)
 @click.option('--rebuild', help="Reconstruct existing overviews.",
               is_flag=True, default=False)
 @click.option('--resampling', help="Resampling algorithm.",
               type=click.Choice(
-                  [it.name for it in Resampling if it.value in [0, 2, 5, 6, 7]]),
+                  [it.name for it in Resampling if it.value in [0, 1, 2, 3, 4, 5, 6, 7]]),
               default='nearest', show_default=True)
 @click.pass_context
 def overview(ctx, input, build, ls, rebuild, resampling):
@@ -52,10 +85,15 @@ def overview(ctx, input, build, ls, rebuild, resampling):
 
       rio overview --build 2,4,8,16
 
-    or a base and range of exponents.
+    or a base and range of exponents
 
       rio overview --build 2^1..4
 
+    or 'auto' to automatically determine the maximum decimation level at
+    which the smallest overview is smaller than 256 pixels in size.
+
+      rio overview --build auto
+
     Note that overviews can not currently be removed and are not
     automatically updated when the dataset's primary bands are
     modified.
@@ -66,12 +104,9 @@ def overview(ctx, input, build, ls, rebuild, resampling):
       rio overview --ls
 
     """
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-
-    with rasterio.Env(CPL_DEBUG=(verbosity > 2)):
-        with rasterio.open(input, 'r+') as dst:
-
-            if ls:
+    with ctx.obj['env']:
+        if ls:
+            with rasterio.open(input, 'r') as dst:
                 resampling_method = dst.tags(
                     ns='rio_overview').get('resampling') or 'unknown'
 
@@ -79,8 +114,8 @@ def overview(ctx, input, build, ls, rebuild, resampling):
                 for idx in dst.indexes:
                     click.echo("  Band %d: %s (method: '%s')" % (
                         idx, dst.overviews(idx) or 'None', resampling_method))
-
-            elif rebuild:
+        elif rebuild:
+            with rasterio.open(input, 'r+') as dst:
                 # Build the same overviews for all bands.
                 factors = reduce(
                     operator.or_,
@@ -93,8 +128,16 @@ def overview(ctx, input, build, ls, rebuild, resampling):
                 dst.build_overviews(
                     list(factors), Resampling[resampling_method])
 
-            elif build:
+        elif build:
+            with rasterio.open(input, 'r+') as dst:
+                if build == "auto":
+                    overview_level = get_maximum_overview_level(dst.width, dst.height)
+                    build = [2 ** j for j in range(1, overview_level + 1)]
                 dst.build_overviews(build, Resampling[resampling])
 
                 # Save the resampling method to a tag.
                 dst.update_tags(ns='rio_overview', resampling=resampling)
+
+        else:
+            raise click.UsageError(
+                "Please specify --ls, --rebuild, or --build ...")
