@@ -1,27 +1,27 @@
-"""Commands for operating on bands of datasets."""
-import collections
+"""$ rio stack"""
+
+
 import logging
 
 import click
-from cligj import files_inout_arg, format_opt
+from cligj import format_opt
 
-from .helpers import resolve_inout
-from . import options
 import rasterio
-from rasterio.compat import zip_longest
+from rasterio.compat import Iterable, zip_longest
+from rasterio.rio import options
+from rasterio.rio.helpers import resolve_inout
 
 
-# Stack command.
 @click.command(short_help="Stack a number of bands into a multiband dataset.")
-@files_inout_arg
+@options.files_inout_arg
 @options.output_opt
 @format_opt
-@options.bidx_mult_opt
+@options.bidx_magic_opt
 @options.rgb_opt
-@options.force_overwrite_opt
+@options.overwrite_opt
 @options.creation_options
 @click.pass_context
-def stack(ctx, files, output, driver, bidx, photometric, force_overwrite,
+def stack(ctx, files, output, driver, bidx, photometric, overwrite,
           creation_options):
     """Stack a number of bands from one or more input files into a
     multiband dataset.
@@ -54,12 +54,11 @@ def stack(ctx, files, output, driver, bidx, photometric, force_overwrite,
       rio stack RGB.byte.tif --bidx ..2 RGB.byte.tif --bidx 3.. -o stacked.tif
 
     """
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 2
-    logger = logging.getLogger('rio')
+    logger = logging.getLogger(__name__)
     try:
-        with rasterio.Env(CPL_DEBUG=verbosity > 2):
+        with ctx.obj['env']:
             output, files = resolve_inout(files=files, output=output,
-                                          force_overwrite=force_overwrite)
+                                          overwrite=overwrite)
             output_count = 0
             indexes = []
             for path, item in zip_longest(files, bidx, fillvalue=None):
@@ -88,7 +87,6 @@ def stack(ctx, files, output, driver, bidx, photometric, force_overwrite,
             with rasterio.open(files[0]) as first:
                 kwargs = first.meta
                 kwargs.update(**creation_options)
-                kwargs['transform'] = kwargs.pop('affine')
 
             kwargs.update(
                 driver=driver,
@@ -105,7 +103,7 @@ def stack(ctx, files, output, driver, bidx, photometric, force_overwrite,
                             data = src.read(index)
                             dst.write(data, dst_idx)
                             dst_idx += 1
-                        elif isinstance(index, collections.Iterable):
+                        elif isinstance(index, Iterable):
                             data = src.read(index)
                             dst.write(data, range(dst_idx, dst_idx + len(index)))
                             dst_idx += len(index)
