@@ -1,22 +1,19 @@
 """Raster warping and reprojection."""
 
 
-from __future__ import absolute_import
-from __future__ import division
+from __future__ import absolute_import, division
 
 from math import ceil, floor
 
-from affine import Affine
 import numpy as np
-
 import rasterio
+from affine import Affine
 from rasterio._base import _transform
-from rasterio._warp import (
-    _transform_geom, _reproject, _calculate_default_transform)
+from rasterio._warp import _calculate_default_transform, _reproject, _transform_geom
 from rasterio.enums import Resampling
-from rasterio.env import ensure_env, GDALVersion, require_gdal_version
+from rasterio.env import GDALVersion, ensure_env, require_gdal_version
 from rasterio.errors import GDALBehaviorChangeException
-
+from rasterio.transform import array_bounds
 
 # Gauss (7) is not supported for warp
 SUPPORTED_RESAMPLING = [r for r in Resampling if r.value < 7]
@@ -175,9 +172,9 @@ def transform_bounds(
 
 @ensure_env
 @require_gdal_version('2.0', param='resampling', values=GDAL2_RESAMPLING)
-def reproject(source, destination, src_transform=None, gcps=None,
+def reproject(source, destination=None, src_transform=None, gcps=None,
               src_crs=None, src_nodata=None, dst_transform=None, dst_crs=None,
-              dst_nodata=None, src_alpha=0, dst_alpha=0,
+              dst_nodata=None, dst_resolution=None, src_alpha=0, dst_alpha=0,
               resampling=Resampling.nearest, num_threads=1,
               init_dest_nodata=True, warp_mem_limit=0, **kwargs):
     """Reproject a source raster to a destination raster.
@@ -192,9 +189,15 @@ def reproject(source, destination, src_transform=None, gcps=None,
 
     Parameters
     ------------
-    source, destination: ndarray or Band
-        The source and destination are 2 or 3-D ndarrays, or a single
-        or multiple Rasterio Band object. The dimensionality of source
+    source: ndarray or Band
+        The source is a 2 or 3-D ndarray, or a single or a multiple
+        Rasterio Band object. The dimensionality of source
+        and destination must match, i.e., for multiband reprojection
+        the lengths of the first axes of the source and destination
+        must be the same.
+    destination: ndarray or Band, optional
+        The destination is a 2 or 3-D ndarray, or a single or a multiple
+        Rasterio Band object. The dimensionality of source
         and destination must match, i.e., for multiband reprojection
         the lengths of the first axes of the source and destination
         must be the same.
@@ -229,6 +232,9 @@ def reproject(source, destination, src_transform=None, gcps=None,
         remain in all areas not covered by the reprojected source.
         Defaults to the nodata value of the destination image (if set),
         the value of src_nodata, or 0 (GDAL default).
+    dst_resolution: tuple (x resolution, y resolution) or float, optional
+        Target resolution, in units of target coordinate reference
+        system.
     src_alpha : int, optional
         Index of a band to use as the alpha band when warping.
     dst_alpha : int, optional
@@ -265,8 +271,10 @@ def reproject(source, destination, src_transform=None, gcps=None,
 
     Returns
     ---------
-    out: None
-        Output is written to destination.
+    destination: ndarray or Band
+        The transformed narray or Band.
+    dst_transform: Affine
+        THe affine transformation matrix of the destination.
     """
 
     # Only one type of georeferencing is permitted.
@@ -287,6 +295,48 @@ def reproject(source, destination, src_transform=None, gcps=None,
                 ['Resampling.{0}'.format(r.name) for r in
                  SUPPORTED_RESAMPLING])))
 
+    if destination is None and dst_transform is not None:
+        raise ValueError("Must provide destination if dst_transform is provided.")
+
+    # calculate the destination transform if not provided
+    if dst_transform is None and (destination is None or isinstance(destination, np.ndarray)):
+        if isinstance(source, np.ndarray):
+            if source.ndim == 3:
+                src_count, src_height, src_width = source.shape
+            else:
+                src_count = 1
+                src_height, src_width = source.shape
+            src_bounds = array_bounds(src_height, src_width, src_transform)
+        else:
+            src_rdr, src_bidx, _, src_shape = source
+            src_bounds = src_rdr.bounds
+            src_crs = src_rdr.crs
+            if isinstance(src_bidx, int):
+                src_bidx = [src_bidx]
+            src_count = len(src_bidx)
+            src_height, src_width = src_shape
+
+        dst_height = None
+        dst_width = None
+        dst_count = src_count
+        if isinstance(destination, np.ndarray):
+            if destination.ndim == 3:
+                dst_count, dst_height, dst_width = destination.shape
+            else:
+                dst_count = 1
+                dst_height, dst_width = destination.shape
+
+        left, bottom, right, top = src_bounds
+        dst_transform, dst_width, dst_height = calculate_default_transform(
+            src_crs=src_crs, dst_crs=dst_crs, width=src_width, height=src_height,
+            left=left, bottom=bottom, right=right, top=top,
+            gcps=gcps, dst_width=dst_width, dst_height=dst_height,
+            resolution=dst_resolution)
+
+        if destination is None:
+            destination = np.empty((int(dst_count), int(dst_height), int(dst_width)),
+                                   dtype=source.dtype)
+
     # Call the function in our extension module.
     _reproject(
         source, destination, src_transform=src_transform, gcps=gcps,
@@ -296,6 +346,8 @@ def reproject(source, destination, src_transform=None, gcps=None,
         init_dest_nodata=init_dest_nodata, num_threads=num_threads,
         warp_mem_limit=warp_mem_limit, **kwargs)
 
+    return destination, dst_transform
+
 
 def aligned_target(transform, width, height, resolution):
     """Aligns target to specified resolution
