@@ -13,7 +13,7 @@ def mock_wheel(tmpdir):
     moduledir = tmpdir.mkdir("rasterio")
     moduledir.ensure("__init__.py")
     moduledir.ensure("_env.py")
-    moduledir.ensure("gdal_data/pcs.csv")
+    moduledir.ensure("gdal_data/header.dxf")
     moduledir.ensure("proj_data/epsg")
     return moduledir
 
@@ -21,7 +21,7 @@ def mock_wheel(tmpdir):
 @pytest.fixture
 def mock_fhs(tmpdir):
     """A fake FHS system"""
-    tmpdir.ensure("share/gdal/pcs.csv")
+    tmpdir.ensure("share/gdal/header.dxf")
     tmpdir.ensure("share/proj/epsg")
     return tmpdir
 
@@ -29,13 +29,13 @@ def mock_fhs(tmpdir):
 @pytest.fixture
 def mock_debian(tmpdir):
     """A fake Debian multi-install system"""
-    tmpdir.ensure("share/gdal/1.11/pcs.csv")
-    tmpdir.ensure("share/gdal/2.0/pcs.csv")
-    tmpdir.ensure("share/gdal/2.1/pcs.csv")
-    tmpdir.ensure("share/gdal/2.2/pcs.csv")
-    tmpdir.ensure("share/gdal/2.3/pcs.csv")
-    tmpdir.ensure("share/gdal/2.4/pcs.csv")
-    tmpdir.ensure("share/gdal/3.0/pcs.csv")
+    tmpdir.ensure("share/gdal/1.11/header.dxf")
+    tmpdir.ensure("share/gdal/2.0/header.dxf")
+    tmpdir.ensure("share/gdal/2.1/header.dxf")
+    tmpdir.ensure("share/gdal/2.2/header.dxf")
+    tmpdir.ensure("share/gdal/2.3/header.dxf")
+    tmpdir.ensure("share/gdal/2.4/header.dxf")
+    tmpdir.ensure("share/gdal/3.0/header.dxf")
     tmpdir.ensure("share/proj/epsg")
     return tmpdir
 
