@@ -7,9 +7,11 @@ import pytest
 
 import rasterio
 from rasterio._env import GDALDataFinder, PROJDataFinder
+from .conftest import requires_gdal_lt_3
 from rasterio.rio.main import main_group
 
 
+@requires_gdal_lt_3
 @pytest.mark.wheel
 def test_gdal_data():
     """Get GDAL data path from a wheel"""
@@ -21,6 +23,7 @@ def test_gdal_data_find_file():
     GDALDataFinder().find_file("header.dxf")
 
 
+@requires_gdal_lt_3
 @pytest.mark.wheel
 def test_proj_data():
     """Get GDAL data path from a wheel"""
@@ -32,6 +35,7 @@ def test_proj_data_has_data():
     PROJDataFinder().has_data()
 
 
+@requires_gdal_lt_3
 @pytest.mark.wheel
 def test_env_gdal_data():
     runner = CliRunner()
@@ -40,6 +44,7 @@ def test_env_gdal_data():
     assert result.output.strip() == os.path.join(os.path.dirname(rasterio.__file__), 'gdal_data')
 
 
+@requires_gdal_lt_3
 @pytest.mark.wheel
 def test_env_proj_data():
     runner = CliRunner()
