@@ -5,7 +5,7 @@ import click
 from click.testing import CliRunner
 
 import rasterio
-from rasterio.rio import sample
+from rasterio.rio.main import main_group
 
 
 logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
@@ -14,8 +14,8 @@ logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 def test_sample_err():
     runner = CliRunner()
     result = runner.invoke(
-        sample.sample,
-        ['bogus.tif'],
+        main_group,
+        ['sample', 'bogus.tif'],
         "[220650.0, 2719200.0]")
     assert result.exit_code == 1
 
@@ -23,8 +23,8 @@ def test_sample_err():
 def test_sample_stdin():
     runner = CliRunner()
     result = runner.invoke(
-        sample.sample,
-        ['tests/data/RGB.byte.tif'],
+        main_group,
+        ['sample', 'tests/data/RGB.byte.tif'],
         "[220650.0, 2719200.0]\n[220650.0, 2719200.0]",
         catch_exceptions=False)
     assert result.exit_code == 0
@@ -34,8 +34,8 @@ def test_sample_stdin():
 def test_sample_arg():
     runner = CliRunner()
     result = runner.invoke(
-        sample.sample,
-        ['tests/data/RGB.byte.tif', "[220650.0, 2719200.0]"],
+        main_group,
+        ['sample', 'tests/data/RGB.byte.tif', "[220650.0, 2719200.0]"],
         catch_exceptions=False)
     assert result.exit_code == 0
     assert result.output.strip() == '[18, 25, 14]'
@@ -44,8 +44,8 @@ def test_sample_arg():
 def test_sample_bidx():
     runner = CliRunner()
     result = runner.invoke(
-        sample.sample,
-        ['tests/data/RGB.byte.tif', '--bidx', '1,2', "[220650.0, 2719200.0]"],
+        main_group,
+        ['sample', 'tests/data/RGB.byte.tif', '--bidx', '1,2', "[220650.0, 2719200.0]"],
         catch_exceptions=False)
     assert result.exit_code == 0
     assert result.output.strip() == '[18, 25]'
@@ -54,8 +54,8 @@ def test_sample_bidx():
 def test_sample_bidx2():
     runner = CliRunner()
     result = runner.invoke(
-        sample.sample,
-        ['tests/data/RGB.byte.tif', '--bidx', '1..2', "[220650.0, 2719200.0]"],
+        main_group,
+        ['sample', 'tests/data/RGB.byte.tif', '--bidx', '1..2', "[220650.0, 2719200.0]"],
         catch_exceptions=False)
     assert result.exit_code == 0
     assert result.output.strip() == '[18, 25]'
@@ -64,8 +64,8 @@ def test_sample_bidx2():
 def test_sample_bidx3():
     runner = CliRunner()
     result = runner.invoke(
-        sample.sample,
-        ['tests/data/RGB.byte.tif', '--bidx', '..2', "[220650.0, 2719200.0]"],
+        main_group,
+        ['sample', 'tests/data/RGB.byte.tif', '--bidx', '..2', "[220650.0, 2719200.0]"],
         catch_exceptions=False)
     assert result.exit_code == 0
     assert result.output.strip() == '[18, 25]'
@@ -74,8 +74,8 @@ def test_sample_bidx3():
 def test_sample_bidx4():
     runner = CliRunner()
     result = runner.invoke(
-        sample.sample,
-        ['tests/data/RGB.byte.tif', '--bidx', '3', "[220650.0, 2719200.0]"],
+        main_group,
+        ['sample', 'tests/data/RGB.byte.tif', '--bidx', '3', "[220650.0, 2719200.0]"],
         catch_exceptions=False)
     assert result.exit_code == 0
     assert result.output.strip() == '[14]'
