@@ -108,6 +108,15 @@ def test_session_factory_s3():
     assert isinstance(sesh, AWSSession)
 
 
+def test_session_factory_s3_no_boto3(monkeypatch):
+    """Get an AWSSession for s3:// paths"""
+    pytest.importorskip("boto3")
+    with monkeypatch.context() as mpctx:
+        mpctx.setattr("rasterio.session.boto3", None)
+        sesh = Session.from_path("s3://lol/wut")
+        assert isinstance(sesh, DummySession)
+
+
 def test_session_factory_s3_kwargs():
     """Get an AWSSession for s3:// paths with keywords"""
     pytest.importorskip("boto3")
@@ -202,4 +211,16 @@ def test_session_factory_swift_kwargs():
     sesh = Session.from_path("/vsiswift/lol/wut", swift_storage_url='foo', swift_auth_token='bar')
     assert isinstance(sesh, DummySession)
 
-    
+
+def test_session_aws_or_dummy_aws():
+    """Get an AWSSession when boto3 is available"""
+    boto3 = pytest.importorskip("boto3")
+    assert isinstance(Session.aws_or_dummy(), AWSSession)
+
+
+def test_session_aws_or_dummy_dummy(monkeypatch):
+    """Get a DummySession when boto3 is not available"""
+    boto3 = pytest.importorskip("boto3")
+    with monkeypatch.context() as mpctx:
+        mpctx.setattr("rasterio.session.boto3", None)
+        assert isinstance(Session.aws_or_dummy(), DummySession)
